@@ -81,6 +81,8 @@ def get_pipfile_deps():
     pipfile_deps = read_pipfile()
     for dep in pipfile_deps.keys():
         dep_spec = pipfile_deps[dep]
+        if isinstance(dep_spec, dict):
+            dep_spec = dep_spec['version']
         pipfile_deps[dep] = re.findall(spec_exp, dep_spec)
 
     pipfile_deps = split_ops_and_versions(pipfile_deps)
@@ -211,7 +213,7 @@ def version_check(setup_deps, pipfile_deps):
                         pipfile_version = parse_version(pipfile_dep_spec[1])
                         check_args["right_op"] = pipfile_op
                         check_args["right_version"] = pipfile_version
-                        print(check_args)
+
                         if not check_fn(**check_args):
                             problem_deps.append(dep_name)
 
